@@ -33,11 +33,8 @@ import unittest
 
 import bs4
 import httpretty
-import pkg_resources
 import requests
 
-pkg_resources.declare_namespace('perceval.backends')
-
 from perceval.backend import BackendCommandArgumentParser
 from perceval.backends.core.askbot import (Askbot,
                                            AskbotClient,
