@@ -29,7 +29,6 @@ import datetime
 import dateutil.tz
 import httpretty
 import os
-import pkg_resources
 import time
 import unittest
 import unittest.mock
@@ -37,8 +36,6 @@ import warnings
 
 import requests
 
-pkg_resources.declare_namespace('perceval.backends')
-
 from perceval.backend import BackendCommandArgumentParser
 from perceval.errors import RateLimitError, RepositoryError
 from perceval.utils import DEFAULT_DATETIME
